@@ -52,6 +52,7 @@ const (
 	migrateApplyAllowDirty      = "allow-dirty"
 	migrateApplyFromVersion     = "from"
 	migrateApplyBaselineVersion = "baseline"
+	migrateApplyTxMode          = "tx-mode"
 )
 
 var (
@@ -71,6 +72,7 @@ var (
 			AllowDirty      bool
 			FromVersion     string
 			BaselineVersion string
+			TxMode          string
 		}
 		Diff struct {
 			Qualifier string // optional table qualifier
@@ -241,11 +243,14 @@ func init() {
 	MigrateApplyCmd.Flags().StringVarP(&MigrateFlags.Apply.LogFormat, migrateFlagLog, "", logFormatTTY, "log format to use")
 	revisionsFlag(MigrateApplyCmd.Flags())
 	MigrateApplyCmd.Flags().BoolVarP(&MigrateFlags.Apply.DryRun, migrateFlagDryRun, "", false, "do not actually execute any SQL but show it on screen")
-	MigrateApplyCmd.Flags().StringVarP(&MigrateFlags.Apply.BaselineVersion, migrateApplyFromVersion, "", "", "calculate pending files from the given version (including it)")
+	MigrateApplyCmd.Flags().StringVarP(&MigrateFlags.Apply.FromVersion, migrateApplyFromVersion, "", "", "calculate pending files from the given version (including it)")
 	MigrateApplyCmd.Flags().StringVarP(&MigrateFlags.Apply.BaselineVersion, migrateApplyBaselineVersion, "", "", "start the first migration after the given baseline version")
+	MigrateApplyCmd.Flags().StringVarP(&MigrateFlags.Apply.TxMode, migrateApplyTxMode, "", txModeFile, "set transaction mode [none, file, all]")
 	MigrateApplyCmd.Flags().BoolVarP(&MigrateFlags.Apply.AllowDirty, migrateApplyAllowDirty, "", false, "allow start working on a non-clean database")
 	urlFlag(&MigrateFlags.URL, migrateFlagURL, "u", MigrateApplyCmd.Flags())
+	MigrateApplyCmd.Flags().SortFlags = false
 	cobra.CheckErr(MigrateApplyCmd.MarkFlagRequired(migrateFlagURL))
+	MigrateApplyCmd.MarkFlagsMutuallyExclusive(migrateApplyFromVersion, migrateApplyBaselineVersion)
 	// Diff flags.
 	urlFlag(&MigrateFlags.DevURL, migrateFlagDevURL, "", MigrateDiffCmd.Flags())
 	MigrateDiffCmd.Flags().StringSliceVarP(&MigrateFlags.ToURLs, migrateFlagTo, "", nil, "[driver://username:password@address/dbname?param=value ...] select a desired state using the URL format")
@@ -306,21 +311,13 @@ func CmdMigrateApplyRun(cmd *cobra.Command, args []string) error {
 		return err
 	}
 	var rrw migrate.RevisionReadWriter
-	rrw, err = entmigrate.NewEntRevisions(c, []entmigrate.Option{entmigrate.WithSchema(MigrateFlags.RevisionSchema)}...)
+	rrw, err = entRevisions(cmd.Context(), c)
 	if err != nil {
 		return err
 	}
-	if err := rrw.(*entmigrate.EntRevisions).Init(cmd.Context()); err != nil {
+	if err := rrw.(*entmigrate.EntRevisions).Migrate(cmd.Context()); err != nil {
 		return err
 	}
-	defer func(rrw *entmigrate.EntRevisions) {
-		if err2 := rrw.Flush(cmd.Context()); err2 != nil {
-			if err != nil {
-				err2 = fmt.Errorf("%w: %v", err, err2)
-			}
-			err = err2
-		}
-	}(rrw.(*entmigrate.EntRevisions))
 	// Determine pending files and lock the database while working.
 	ex, err := migrate.NewExecutor(c.Driver, dir, rrw, executorOptions(l)...)
 	if err != nil {
@@ -349,46 +346,121 @@ func CmdMigrateApplyRun(cmd *cobra.Command, args []string) error {
 		return err
 	}
 	var (
+		mux = tx{c: c, rrw: rrw}
 		drv migrate.Driver
-		tx  *sqlclient.TxClient
 	)
-	if MigrateFlags.Apply.DryRun {
-		drv = &dryRunDriver{c.Driver}
-		rrw = &dryRunRevisions{rrw}
-	}
 	for _, f := range pending {
-		if !MigrateFlags.Apply.DryRun {
-			// Wrap the file execution in a transaction.
-			tx, err = c.Tx(cmd.Context(), nil)
-			if err != nil {
-				return err
-			}
-			drv = tx.Driver
+		drv, rrw, err = mux.driver(cmd.Context())
+		if err != nil {
+			return err
 		}
 		ex, err := migrate.NewExecutor(drv, dir, rrw, executorOptions(l)...)
 		if err != nil {
 			return err
 		}
-		if err := ex.Execute(cmd.Context(), f); err != nil {
-			if !MigrateFlags.Apply.DryRun {
-				if err2 := tx.Rollback(); err2 != nil {
-					err = fmt.Errorf("%v: %w", err2, err)
-				}
-			}
+		if err := mux.mayRollback(ex.Execute(cmd.Context(), f)); err != nil {
 			return err
 		}
-		if !MigrateFlags.Apply.DryRun {
-			if err := tx.Commit(); err != nil {
-				return err
-			}
+		if err := mux.mayCommit(); err != nil {
+			return err
 		}
 	}
+	if err := mux.commit(); err != nil {
+		return err
+	}
 	l.Log(migrate.LogDone{})
+	return mux.commit()
+}
+
+func entRevisions(ctx context.Context, c *sqlclient.Client) (*entmigrate.EntRevisions, error) {
+	return entmigrate.NewEntRevisions(ctx, c, entmigrate.WithSchema(MigrateFlags.RevisionSchema))
+}
+
+// tx handles wrapping migration execution in transactions.
+type tx struct {
+	c   *sqlclient.Client
+	tx  *sqlclient.TxClient
+	rrw migrate.RevisionReadWriter
+}
+
+// driver returns the migrate.Driver to use to execute migration statements.
+func (tx *tx) driver(ctx context.Context) (migrate.Driver, migrate.RevisionReadWriter, error) {
+	if MigrateFlags.Apply.DryRun {
+		// If the --dry-run flag is given we don't want to execute any statements on the database.
+		return &dryRunDriver{tx.c.Driver}, &dryRunRevisions{tx.rrw}, nil
+	}
+	switch MigrateFlags.Apply.TxMode {
+	case txModeNone:
+		return tx.c.Driver, tx.rrw, nil
+	case txModeFile:
+		// In file-mode, this function is called each time a new file is executed. Open a transaction.
+		if tx.tx != nil {
+			return nil, nil, errors.New("unexpected active transaction")
+		}
+		var err error
+		tx.tx, err = tx.c.Tx(ctx, nil)
+		if err != nil {
+			return nil, nil, err
+		}
+		tx.rrw, err = entRevisions(ctx, tx.tx.Client)
+		if err != nil {
+			return nil, nil, err
+		}
+		return tx.tx.Driver, tx.rrw, nil
+	case txModeAll:
+		// In file-mode, this function is called each time a new file is executed. Since we wrap all files into one
+		// huge transaction, if there already is an opened one, use that.
+		if tx.tx == nil {
+			var err error
+			tx.tx, err = tx.c.Tx(ctx, nil)
+			if err != nil {
+				return nil, nil, err
+			}
+			tx.rrw, err = entRevisions(ctx, tx.tx.Client)
+			if err != nil {
+				return nil, nil, err
+			}
+		}
+		return tx.tx.Driver, tx.rrw, nil
+	default:
+		return nil, nil, fmt.Errorf("unknown tx-mode %q", MigrateFlags.Apply.TxMode)
+	}
+}
+
+// mayRollback may roll back a transaction depending on the given transaction mode.
+func (tx *tx) mayRollback(err error) error {
+	if tx.tx != nil && err != nil {
+		if err2 := tx.tx.Rollback(); err2 != nil {
+			err = fmt.Errorf("%v: %w", err2, err)
+		}
+	}
+	return err
+}
+
+// mayCommit may commit a transaction depending on the given transaction mode.
+func (tx *tx) mayCommit() error {
+	// Only commit if each file is wrapped in a transaction.
+	if !MigrateFlags.Apply.DryRun && MigrateFlags.Apply.TxMode == txModeFile {
+		return tx.commit()
+	}
 	return nil
 }
 
+// commit the transaction, if one is active.
+func (tx *tx) commit() error {
+	if tx.tx == nil {
+		return nil
+	}
+	defer func() { tx.tx = nil }()
+	return tx.tx.Commit()
+}
+
 func executorOptions(l migrate.Logger) []migrate.ExecutorOption {
-	opts := []migrate.ExecutorOption{migrate.WithLogger(l)}
+	v, _ := parse(version)
+	opts := []migrate.ExecutorOption{
+		migrate.WithLogger(l),
+		migrate.WithOperatorVersion("Atlas CLI - " + v),
+	}
 	if MigrateFlags.Apply.AllowDirty {
 		opts = append(opts, migrate.WithAllowDirty(true))
 	}
@@ -519,14 +591,10 @@ func CmdMigrateStatusRun(cmd *cobra.Command, _ []string) error {
 		return statusPrint(cmd.OutOrStdout(), avail, avail, nil)
 	}
 	// Currently, only in DB revisions are supported.
-	opts := []entmigrate.Option{entmigrate.WithSchema(MigrateFlags.RevisionSchema)}
-	rrw, err := entmigrate.NewEntRevisions(client, opts...)
+	rrw, err := entmigrate.NewEntRevisions(cmd.Context(), client, entmigrate.WithSchema(MigrateFlags.RevisionSchema))
 	if err != nil {
 		return err
 	}
-	if err := rrw.Init(cmd.Context()); err != nil {
-		return err
-	}
 	// Executor can give us insights on the revision state.
 	ex, err := migrate.NewExecutor(client.Driver, dir, rrw)
 	if err != nil {
@@ -543,7 +611,7 @@ func CmdMigrateStatusRun(cmd *cobra.Command, _ []string) error {
 	return statusPrint(cmd.OutOrStdout(), avail, pending, revs)
 }
 
-func statusPrint(out io.Writer, avail, pending []migrate.File, revs migrate.Revisions) (err error) {
+func statusPrint(out io.Writer, avail, pending []migrate.File, revs []*migrate.Revision) (err error) {
 	var (
 		cur, next, state string
 		applied          = avail[: len(avail)-len(pending) : len(avail)-len(pending)]
@@ -679,6 +747,12 @@ func CmdMigrateLintRun(cmd *cobra.Command, _ []string) error {
 	return err
 }
 
+const (
+	txModeNone = "none"
+	txModeAll  = "all"
+	txModeFile = "file"
+)
+
 func printChecksumErr(out io.Writer) {
 	fmt.Fprintf(out, `You have a checksum error in your migration directory.
 This happens if you manually create or edit a migration file.
@@ -741,7 +815,7 @@ func dir(create bool) (migrate.Dir, error) {
 		f = func() (migrate.Dir, error) { return sqltool.NewFlywayDir(parts[1]) }
 	case formatLiquibase:
 		f = func() (migrate.Dir, error) { return sqltool.NewLiquibaseDir(parts[1]) }
-	case formatDbmate:
+	case formatDBMate:
 		f = func() (migrate.Dir, error) { return sqltool.NewDBMateDir(parts[1]) }
 	default:
 		return nil, fmt.Errorf("unknown dir format %q", MigrateFlags.DirFormat)
@@ -931,7 +1005,7 @@ const (
 	formatGoose         = "goose"
 	formatFlyway        = "flyway"
 	formatLiquibase     = "liquibase"
-	formatDbmate        = "dbmate"
+	formatDBMate        = "dbmate"
 )
 
 func formatter() (migrate.Formatter, error) {
@@ -946,7 +1020,7 @@ func formatter() (migrate.Formatter, error) {
 		return sqltool.FlywayFormatter, nil
 	case formatLiquibase:
 		return sqltool.LiquibaseFormatter, nil
-	case formatDbmate:
+	case formatDBMate:
 		return sqltool.DBMateFormatter, nil
 	default:
 		return nil, fmt.Errorf("unknown format %q", MigrateFlags.DirFormat)
@@ -1083,14 +1157,10 @@ func migrateFlagsFromEnv(cmd *cobra.Command, _ []string) error {
 
 type (
 	// dryRunDriver wraps a migrate.Driver without executing any SQL statements.
-	dryRunDriver struct {
-		migrate.Driver
-	}
+	dryRunDriver struct{ migrate.Driver }
 
 	// dryRunRevisions wraps a migrate.RevisionReadWriter without executing any SQL statements.
-	dryRunRevisions struct {
-		migrate.RevisionReadWriter
-	}
+	dryRunRevisions struct{ migrate.RevisionReadWriter }
 )
 
 // QueryContext overrides the wrapped schema.ExecQuerier to not execute any SQL.
