@@ -29,11 +29,14 @@ func (Revision) Fields() []ent.Field {
 		field.String("description").
 			Immutable(),
 		field.Uint("type").
-			GoType(migrate.RevisionType(0)),
+			GoType(migrate.RevisionType(0)).
+			Default(uint(migrate.RevisionTypeExecute)),
 		field.Int("applied").
-			NonNegative(),
+			NonNegative().
+			Default(0),
 		field.Int("total").
-			NonNegative(),
+			NonNegative().
+			Default(0),
 		field.Time("executed_at").
 			Immutable(),
 		field.Int64("execution_time").
