@@ -54,7 +54,7 @@ module.exports = {
           position: 'right',
         },
         {
-          to: 'cli/getting-started/setting-up',
+          to: 'getting-started',
           label: 'Docs',
           position: 'left',
         },
@@ -76,7 +76,7 @@ module.exports = {
         {
           "title": "Docs",
           "items": [
-            {"label": "Getting Started", "to": "cli/getting-started/setting-up"},
+            {"label": "Getting Started", "to": "getting-started"},
             {"label": "Data Definition Language ", "to": "concepts/ddl"},
             {"label": "CLI Reference", "to": "cli-reference"},
             {"label": "Blog", "to": "blog"},
@@ -106,7 +106,7 @@ module.exports = {
       Copyright © ${new Date().getFullYear()} The Atlas Authors.
       The Go gopher was designed by <a href="http://reneefrench.blogspot.com/">Renee French</a>.
       <br/>
-      The design is licensed under the Creative Commons 3.0 Attributions license. Read this 
+      The design for the Go gopher is licensed under the Creative Commons 3.0 Attributions license. Read this 
       <a href="https://blog.golang.org/gopher">article</a> for more details.
       <br/>
       `,
@@ -122,6 +122,10 @@ module.exports = {
       '@docusaurus/plugin-client-redirects',
       {
         redirects: [
+          {
+            to: '/getting-started/',
+            from: '/cli/getting-started/setting-up',
+          },
           {
             to: '/integrations/terraform-provider',
             from: '/terraform-provider'
