@@ -8,9 +8,9 @@ import (
 	"context"
 	"database/sql"
 	"fmt"
-	"io"
 	"log"
 	"strings"
+	"sync"
 	"testing"
 
 	"ariga.io/atlas/sql/migrate"
@@ -31,59 +31,38 @@ type crdbTest struct {
 	rrw     migrate.RevisionReadWriter
 	version string
 	port    int
+	once    sync.Once
 }
 
-var crdbTests = struct {
-	drivers map[string]*crdbTest
-	ports   map[string]int
-}{
-	drivers: make(map[string]*crdbTest),
-	ports: map[string]int{
-		"cockroach": 26257,
-	},
-}
-
-func crdbInit(d string) []io.Closer {
-	var cs []io.Closer
-	if d != "" {
-		p, ok := crdbTests.ports[d]
-		if ok {
-			crdbTests.ports = map[string]int{d: p}
-		} else {
-			crdbTests.ports = make(map[string]int)
-		}
-	}
-	for version, port := range crdbTests.ports {
-		db, err := sql.Open("postgres", fmt.Sprintf("host=localhost port=%d user=root dbname=defaultdb password=pass sslmode=disable", port))
-		if err != nil {
-			log.Fatalln(err)
-		}
-		cs = append(cs, db)
-
-		drv, err := postgres.Open(db)
-		if err != nil {
-			log.Fatalln(err)
-		}
-		crdbTests.drivers[version] = &crdbTest{db: db, drv: drv, version: version, port: port, rrw: &rrw{}}
-	}
-	return cs
+var crdbTests = map[string]*crdbTest{
+	"cockroach": {port: 26257},
 }
 
 func crdbRun(t *testing.T, fn func(*crdbTest)) {
-	for version, tt := range crdbTests.drivers {
-		t.Run(version, func(t *testing.T) {
-			tt := &crdbTest{T: t, db: tt.db, drv: tt.drv, version: version, port: tt.port, rrw: tt.rrw}
-			fn(tt)
-		})
+	for version, tt := range crdbTests {
+		if flagVersion == "" || flagVersion == version {
+			t.Run(version, func(t *testing.T) {
+				tt.once.Do(func() {
+					var err error
+					tt.version = version
+					tt.rrw = &rrw{}
+					tt.db, err = sql.Open("postgres", fmt.Sprintf("host=localhost port=%d user=root dbname=defaultdb password=pass sslmode=disable", tt.port))
+					if err != nil {
+						log.Fatalln(err)
+					}
+					dbs = append(dbs, tt.db) // close connection after all tests have been run
+					tt.drv, err = postgres.Open(tt.db)
+					if err != nil {
+						log.Fatalln(err)
+					}
+				})
+				tt := &crdbTest{T: t, db: tt.db, drv: tt.drv, version: version, port: tt.port, rrw: tt.rrw}
+				fn(tt)
+			})
+		}
 	}
 }
 
-func TestCockroach_EntRevisions(t *testing.T) {
-	crdbRun(t, func(t *crdbTest) {
-		testEntRevisions(t)
-	})
-}
-
 func TestCockroach_Executor(t *testing.T) {
 	crdbRun(t, func(t *crdbTest) {
 		testExecutor(t)
@@ -171,7 +150,7 @@ func TestCockroach_AddColumns(t *testing.T) {
 			&schema.Column{Name: "m", Type: &schema.ColumnType{Type: &schema.BoolType{T: "boolean"}, Null: true}, Default: &schema.Literal{V: "false"}},
 			&schema.Column{Name: "n", Type: &schema.ColumnType{Type: &schema.SpatialType{T: "geometry"}, Null: true}, Default: &schema.Literal{V: "'POINT(1 2)'"}},
 			&schema.Column{Name: "o", Type: &schema.ColumnType{Type: &schema.SpatialType{T: "geometry"}, Null: true}, Default: &schema.Literal{V: "'LINESTRING(0 0, 1440 900)'"}},
-			&schema.Column{Name: "q", Type: &schema.ColumnType{Type: &postgres.ArrayType{T: "text[]"}, Null: true}, Default: &schema.Literal{V: "'{}'"}},
+			&schema.Column{Name: "q", Type: &schema.ColumnType{Type: &postgres.ArrayType{Type: &schema.StringType{T: "text"}, T: "text[]"}, Null: true}, Default: &schema.Literal{V: "'{}'"}},
 		)
 		changes := t.diff(t.loadUsers(), usersT)
 		require.Len(t, changes, 14)
@@ -221,7 +200,7 @@ func TestCockroach_ColumnArray(t *testing.T) {
 		// Add column.
 		usersT.Columns = append(
 			usersT.Columns,
-			&schema.Column{Name: "a", Type: &schema.ColumnType{Raw: "int[]", Type: &postgres.ArrayType{T: "int[]"}}, Default: &schema.Literal{V: "'{1}'"}},
+			&schema.Column{Name: "a", Type: &schema.ColumnType{Raw: "bigint[]", Type: &postgres.ArrayType{Type: &schema.IntegerType{T: "bigint"}, T: "bigint[]"}}, Default: &schema.Literal{V: "'{1}'"}},
 		)
 		changes := t.diff(t.loadUsers(), usersT)
 		require.Len(t, changes, 1)
@@ -390,7 +369,7 @@ func TestCockroach_CLI(t *testing.T) {
 			}`
 	t.Run("SchemaInspect", func(t *testing.T) {
 		crdbRun(t, func(t *crdbTest) {
-			testCLISchemaInspect(t, h, t.dsn(), postgres.UnmarshalHCL, "-s", "public")
+			testCLISchemaInspect(t, h, t.dsn(), postgres.EvalHCL, "-s", "public")
 		})
 	})
 	t.Run("SchemaApply", func(t *testing.T) {
@@ -462,14 +441,14 @@ func TestCockroach_CLI_MultiSchema(t *testing.T) {
 		crdbRun(t, func(t *crdbTest) {
 			t.dropSchemas("test2")
 			t.dropTables("users")
-			testCLIMultiSchemaInspect(t, h, t.dsn(), []string{"public", "test2"}, postgres.UnmarshalHCL)
+			testCLIMultiSchemaInspect(t, h, t.dsn(), []string{"public", "test2"}, postgres.EvalHCL)
 		})
 	})
 	t.Run("SchemaApply", func(t *testing.T) {
 		crdbRun(t, func(t *crdbTest) {
 			t.dropSchemas("test2")
 			t.dropTables("users")
-			testCLIMultiSchemaApply(t, h, t.dsn(), []string{"public", "test2"}, postgres.UnmarshalHCL)
+			testCLIMultiSchemaApply(t, h, t.dsn(), []string{"public", "test2"}, postgres.EvalHCL)
 		})
 	})
 }
@@ -495,7 +474,7 @@ create table atlas_defaults
 		spec, err := postgres.MarshalHCL(realm.Schemas[0])
 		require.NoError(t, err)
 		var s schema.Schema
-		err = postgres.UnmarshalHCL(spec, &s)
+		err = postgres.EvalHCLBytes(spec, &s, nil)
 		require.NoError(t, err)
 		t.dropTables(n)
 		t.applyHcl(string(spec))
@@ -780,7 +759,7 @@ create table atlas_types_sanity
 				},
 				{
 					Name: "tArray",
-					Type: &schema.ColumnType{Type: &postgres.ArrayType{T: "text[]"}, Raw: "ARRAY", Null: true},
+					Type: &schema.ColumnType{Type: &postgres.ArrayType{Type: &schema.StringType{T: "text"}, T: "text[]"}, Raw: "ARRAY", Null: true},
 					Default: &schema.RawExpr{
 						X: "ARRAY[]:::STRING[]",
 					},
@@ -808,7 +787,7 @@ create table atlas_types_sanity
 				},
 				{
 					Name: "tInterval",
-					Type: &schema.ColumnType{Type: &schema.UnsupportedType{T: "interval"}, Raw: "interval", Null: true},
+					Type: &schema.ColumnType{Type: &postgres.IntervalType{T: "interval", Precision: intp(6)}, Raw: "interval", Null: true},
 					Default: &schema.RawExpr{
 						X: "'04:00:00':::INTERVAL",
 					},
@@ -846,7 +825,7 @@ func (t *crdbTest) revisionsStorage() migrate.RevisionReadWriter {
 func (t *crdbTest) applyHcl(spec string) {
 	realm := t.loadRealm()
 	var desired schema.Schema
-	err := postgres.UnmarshalHCL([]byte(spec), &desired)
+	err := postgres.EvalHCLBytes([]byte(spec), &desired, nil)
 	require.NoError(t, err)
 	existing := realm.Schemas[0]
 	diff, err := t.drv.SchemaDiff(existing, &desired)
@@ -1006,7 +985,7 @@ func (t *crdbTest) dropSchemas(names ...string) {
 func (t *crdbTest) applyRealmHcl(spec string) {
 	realm := t.loadRealm()
 	var desired schema.Realm
-	err := postgres.UnmarshalHCL([]byte(spec), &desired)
+	err := postgres.EvalHCLBytes([]byte(spec), &desired, nil)
 	require.NoError(t, err)
 	diff, err := t.drv.RealmDiff(realm, &desired)
 	require.NoError(t, err)
