@@ -8,7 +8,6 @@ import (
 	"context"
 	"database/sql"
 	"fmt"
-	"io"
 	"log"
 	"testing"
 
@@ -25,54 +24,36 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
-var tidbTests = struct {
-	drivers map[string]*myTest
-	ports   map[string]int
-}{
-	drivers: make(map[string]*myTest),
-	ports:   map[string]int{"tidb5": 4309, "tidb6": 4310},
-}
-
-func tidbInit(d string) []io.Closer {
-	var cs []io.Closer
-	if d != "" {
-		p, ok := tidbTests.ports[d]
-		if ok {
-			tidbTests.ports = map[string]int{d: p}
-		} else {
-			tidbTests.ports = make(map[string]int)
-		}
-	}
-	for version, port := range tidbTests.ports {
-		db, err := sql.Open("mysql", fmt.Sprintf("root@tcp(localhost:%d)/test?parseTime=True", port))
-		if err != nil {
-			log.Fatalln(err)
-		}
-		cs = append(cs, db)
-		drv, err := mysql.Open(db)
-		if err != nil {
-			log.Fatalln(err)
-		}
-		tidbTests.drivers[version] = &myTest{db: db, drv: drv, version: version, port: port, rrw: &rrw{}}
-	}
-	return cs
+var tidbTests = map[string]*myTest{
+	"tidb5": {port: 4309},
+	"tidb6": {port: 4310},
 }
 
 func tidbRun(t *testing.T, fn func(*myTest)) {
-	for version, tt := range tidbTests.drivers {
-		t.Run(version, func(t *testing.T) {
-			tt := &myTest{T: t, db: tt.db, drv: tt.drv, version: version, port: tt.port, rrw: tt.rrw}
-			fn(tt)
-		})
+	for version, tt := range tidbTests {
+		if flagVersion == "" || flagVersion == version {
+			t.Run(version, func(t *testing.T) {
+				tt.once.Do(func() {
+					var err error
+					tt.version = version
+					tt.rrw = &rrw{}
+					tt.db, err = sql.Open("mysql", fmt.Sprintf("root@tcp(localhost:%d)/test?parseTime=True", tt.port))
+					if err != nil {
+						log.Fatalln(err)
+					}
+					dbs = append(dbs, tt.db) // close connection after all tests have been run
+					tt.drv, err = mysql.Open(tt.db)
+					if err != nil {
+						log.Fatalln(err)
+					}
+				})
+				tt := &myTest{T: t, db: tt.db, drv: tt.drv, version: version, port: tt.port, rrw: tt.rrw}
+				fn(tt)
+			})
+		}
 	}
 }
 
-func TestTiDB_EntRevisions(t *testing.T) {
-	tidbRun(t, func(t *myTest) {
-		testEntRevisions(t)
-	})
-}
-
 func TestTiDB_AddDropTable(t *testing.T) {
 	tidbRun(t, func(t *myTest) {
 		testAddDrop(t)
@@ -515,7 +496,7 @@ create table atlas_defaults
 		spec, err := mysql.MarshalHCL(realm.Schemas[0])
 		require.NoError(t, err)
 		var s schema.Realm
-		err = mysql.UnmarshalHCL(spec, &s)
+		err = mysql.EvalHCLBytes(spec, &s, nil)
 		require.NoError(t, err)
 		t.dropTables(n)
 		t.applyHcl(string(spec))
@@ -557,7 +538,7 @@ func TestTiDB_CLI_MultiSchema(t *testing.T) {
 			t.dropTables("users")
 			attrs := t.defaultAttrs()
 			charset, collate := attrs[0].(*schema.Charset), attrs[1].(*schema.Collation)
-			testCLIMultiSchemaInspect(t, fmt.Sprintf(h, charset.V, collate.V, charset.V, collate.V), t.dsn(""), []string{"test", "test2"}, mysql.UnmarshalHCL)
+			testCLIMultiSchemaInspect(t, fmt.Sprintf(h, charset.V, collate.V, charset.V, collate.V), t.dsn(""), []string{"test", "test2"}, mysql.EvalHCL)
 		})
 	})
 	t.Run("SchemaApply", func(t *testing.T) {
@@ -566,7 +547,7 @@ func TestTiDB_CLI_MultiSchema(t *testing.T) {
 			t.dropTables("users")
 			attrs := t.defaultAttrs()
 			charset, collate := attrs[0].(*schema.Charset), attrs[1].(*schema.Collation)
-			testCLIMultiSchemaApply(t, fmt.Sprintf(h, charset.V, collate.V, charset.V, collate.V), t.dsn(""), []string{"test", "test2"}, mysql.UnmarshalHCL)
+			testCLIMultiSchemaApply(t, fmt.Sprintf(h, charset.V, collate.V, charset.V, collate.V), t.dsn(""), []string{"test", "test2"}, mysql.EvalHCL)
 		})
 	})
 }
@@ -590,7 +571,7 @@ func TestTiDB_CLI(t *testing.T) {
 		tidbRun(t, func(t *myTest) {
 			attrs := t.defaultAttrs()
 			charset, collate := attrs[0].(*schema.Charset), attrs[1].(*schema.Collation)
-			testCLISchemaInspect(t, fmt.Sprintf(h, charset.V, collate.V), t.dsn("test"), mysql.UnmarshalHCL)
+			testCLISchemaInspect(t, fmt.Sprintf(h, charset.V, collate.V), t.dsn("test"), mysql.EvalHCL)
 		})
 	})
 	t.Run("SchemaApply", func(t *testing.T) {
@@ -776,7 +757,7 @@ create table atlas_types_sanity
 				Columns: []*schema.Column{
 					{
 						Name:    "tBit",
-						Type:    &schema.ColumnType{Type: &mysql.BitType{T: "bit"}, Raw: "bit(10) unsigned", Null: true},
+						Type:    &schema.ColumnType{Type: &mysql.BitType{T: "bit", Size: 10}, Raw: "bit(10) unsigned", Null: true},
 						Default: &schema.Literal{V: "b'1000000001'"},
 					},
 					{
@@ -923,39 +904,39 @@ create table atlas_types_sanity
 					},
 					{
 						Name: "tVarBinary",
-						Type: &schema.ColumnType{Type: &schema.BinaryType{T: "varbinary", Size: 30},
+						Type: &schema.ColumnType{Type: &schema.BinaryType{T: "varbinary", Size: intp(30)},
 							Raw: "varbinary(30)", Null: true},
 						Default: &schema.Literal{V: t.valueByVersion(map[string]string{"mysql8": "0x546974616E"}, t.quoted("Titan"))},
 					},
 					{
 						Name: "tBinary",
-						Type: &schema.ColumnType{Type: &schema.BinaryType{T: "binary", Size: 5},
+						Type: &schema.ColumnType{Type: &schema.BinaryType{T: "binary", Size: intp(5)},
 							Raw: "binary(5)", Null: true},
 						Default: &schema.Literal{V: t.valueByVersion(map[string]string{"mysql8": "0x546974616E"}, t.quoted("Titan"))},
 					},
 					{
 						Name: "tBlob",
-						Type: &schema.ColumnType{Type: &schema.BinaryType{T: "tinyblob", Size: 0},
+						Type: &schema.ColumnType{Type: &schema.BinaryType{T: "tinyblob"},
 							Raw: "tinyblob", Null: true},
 					},
 					{
 						Name: "tTinyBlob",
-						Type: &schema.ColumnType{Type: &schema.BinaryType{T: "tinyblob", Size: 0},
+						Type: &schema.ColumnType{Type: &schema.BinaryType{T: "tinyblob"},
 							Raw: "tinyblob", Null: true},
 					},
 					{
 						Name: "tMediumBlob",
-						Type: &schema.ColumnType{Type: &schema.BinaryType{T: "mediumblob", Size: 0},
+						Type: &schema.ColumnType{Type: &schema.BinaryType{T: "mediumblob"},
 							Raw: "mediumblob", Null: true},
 					},
 					{
 						Name: "tLongBlob",
-						Type: &schema.ColumnType{Type: &schema.BinaryType{T: "longblob", Size: 0},
+						Type: &schema.ColumnType{Type: &schema.BinaryType{T: "longblob"},
 							Raw: "longblob", Null: true},
 					},
 					{
 						Name: "tText",
-						Type: &schema.ColumnType{Type: &schema.StringType{T: "tinytext", Size: 0},
+						Type: &schema.ColumnType{Type: &schema.StringType{T: "tinytext"},
 							Raw: "tinytext", Null: true},
 						Attrs: []schema.Attr{
 							&schema.Charset{V: "latin1"},
@@ -964,7 +945,7 @@ create table atlas_types_sanity
 					},
 					{
 						Name: "tTinyText",
-						Type: &schema.ColumnType{Type: &schema.StringType{T: "tinytext", Size: 0},
+						Type: &schema.ColumnType{Type: &schema.StringType{T: "tinytext"},
 							Raw: "tinytext", Null: true},
 						Attrs: []schema.Attr{
 							&schema.Charset{V: "latin1"},
