@@ -34,7 +34,7 @@ func TestPlanner_WritePlan(t *testing.T) {
 	}
 
 	// DefaultFormatter
-	pl := migrate.NewPlanner(nil, d, migrate.DisableChecksum())
+	pl := migrate.NewPlanner(nil, d, migrate.PlanWithChecksum(false))
 	require.NotNil(t, pl)
 	require.NoError(t, pl.WritePlan(plan))
 	v := time.Now().UTC().Format("20060102150405")
@@ -49,7 +49,7 @@ func TestPlanner_WritePlan(t *testing.T) {
 		template.Must(template.New("").Parse("{{ range .Changes }}{{ println .Reverse }}{{ end }}")),
 	)
 	require.NoError(t, err)
-	pl = migrate.NewPlanner(nil, d, migrate.WithFormatter(fmt), migrate.DisableChecksum())
+	pl = migrate.NewPlanner(nil, d, migrate.PlanFormat(fmt), migrate.PlanWithChecksum(false))
 	require.NotNil(t, pl)
 	require.NoError(t, pl.WritePlan(plan))
 	require.Equal(t, countFiles(t, d), 3)
@@ -179,19 +179,19 @@ func TestExecutor_Pending(t *testing.T) {
 	require.Len(t, p, 3)
 
 	// 2 are pending.
-	*rrw = mockRevisionReadWriter(migrate.Revisions{rev1})
+	*rrw = []*migrate.Revision{rev1}
 	p, err = ex.Pending(context.Background())
 	require.NoError(t, err)
 	require.Len(t, p, 2)
 
 	// Only the last one is pending (in full).
-	*rrw = mockRevisionReadWriter(migrate.Revisions{rev1, rev2})
+	*rrw = []*migrate.Revision{rev1, rev2}
 	p, err = ex.Pending(context.Background())
 	require.NoError(t, err)
 	require.Len(t, p, 1)
 
 	// First statement of last one is marked as applied, second isn't. Third file is still pending.
-	*rrw = mockRevisionReadWriter(migrate.Revisions{rev1, rev2, rev3})
+	*rrw = []*migrate.Revision{rev1, rev2, rev3}
 	p, err = ex.Pending(context.Background())
 	require.NoError(t, err)
 	require.Len(t, p, 1)
@@ -217,7 +217,7 @@ func TestExecutor(t *testing.T) {
 	dir, err = migrate.NewLocalDir(t.TempDir())
 	require.NoError(t, err)
 	require.NoError(t, dir.WriteFile("atlas.sum", hash))
-	ex, err = migrate.NewExecutor(&mockDriver{}, dir, &mockRevisionReadWriter{})
+	ex, err = migrate.NewExecutor(&mockDriver{}, dir, &mockRevisionReadWriter{}, migrate.WithOperatorVersion("op"))
 	require.NoError(t, err)
 	require.NotNil(t, ex)
 	require.ErrorIs(t, ex.ExecuteN(context.Background(), 0), migrate.ErrChecksumMismatch)
@@ -228,25 +228,27 @@ func TestExecutor(t *testing.T) {
 		rrw  = &mockRevisionReadWriter{}
 		log  = &mockLogger{}
 		rev1 = &migrate.Revision{
-			Version:     "1.a",
-			Description: "sub.up",
-			Type:        migrate.RevisionTypeExecute,
-			Applied:     2,
-			Total:       2,
-			Hash:        "nXyZR020M/mH7LxkoTkJr7BcQkipVg90imQ9I4595dw=",
+			Version:         "1.a",
+			Description:     "sub.up",
+			Type:            migrate.RevisionTypeExecute,
+			Applied:         2,
+			Total:           2,
+			Hash:            "nXyZR020M/mH7LxkoTkJr7BcQkipVg90imQ9I4595dw=",
+			OperatorVersion: "op",
 		}
 		rev2 = &migrate.Revision{
-			Version:     "2.10.x-20",
-			Description: "description",
-			Type:        migrate.RevisionTypeExecute,
-			Applied:     1,
-			Total:       1,
-			Hash:        "wQB3Vh3PHVXQg9OD3Gn7TBxbZN3r1Qb7TtAE1g3q9mQ=",
+			Version:         "2.10.x-20",
+			Description:     "description",
+			Type:            migrate.RevisionTypeExecute,
+			Applied:         1,
+			Total:           1,
+			Hash:            "wQB3Vh3PHVXQg9OD3Gn7TBxbZN3r1Qb7TtAE1g3q9mQ=",
+			OperatorVersion: "op",
 		}
 	)
 	dir, err = migrate.NewLocalDir(filepath.Join("testdata/migrate", "sub"))
 	require.NoError(t, err)
-	ex, err = migrate.NewExecutor(drv, dir, rrw, migrate.WithLogger(log))
+	ex, err = migrate.NewExecutor(drv, dir, rrw, migrate.WithLogger(log), migrate.WithOperatorVersion("op"))
 	require.NoError(t, err)
 
 	// Applies two of them.
@@ -254,7 +256,7 @@ func TestExecutor(t *testing.T) {
 	require.Equal(t, drv.executed, []string{
 		"CREATE TABLE t_sub(c int);", "ALTER TABLE t_sub ADD c1 int;", "ALTER TABLE t_sub ADD c2 int;",
 	})
-	requireEqualRevisions(t, migrate.Revisions{rev1, rev2}, migrate.Revisions(*rrw))
+	requireEqualRevisions(t, []*migrate.Revision{rev1, rev2}, *rrw)
 	require.Equal(t, []migrate.LogEntry{
 		migrate.LogExecution{To: "2.10.x-20", Files: []string{"1.a_sub.up.sql", "2.10.x-20_description.sql"}},
 		migrate.LogFile{Version: "1.a", Desc: "sub.up"},
@@ -277,13 +279,13 @@ func TestExecutor(t *testing.T) {
 
 	require.NoError(t, ex.ExecuteN(context.Background(), 1))
 	require.Equal(t, []string{"CREATE TABLE t_sub(c int);", "ALTER TABLE t_sub ADD c1 int;"}, drv.executed)
-	requireEqualRevisions(t, migrate.Revisions{rev1}, migrate.Revisions(*rrw))
+	requireEqualRevisions(t, []*migrate.Revision{rev1}, *rrw)
 
 	require.NoError(t, ex.ExecuteN(context.Background(), 1))
 	require.Equal(t, []string{
 		"CREATE TABLE t_sub(c int);", "ALTER TABLE t_sub ADD c1 int;", "ALTER TABLE t_sub ADD c2 int;",
 	}, drv.executed)
-	requireEqualRevisions(t, migrate.Revisions{rev1, rev2}, migrate.Revisions(*rrw))
+	requireEqualRevisions(t, []*migrate.Revision{rev1, rev2}, *rrw)
 
 	// Partly is pending.
 	p, err = ex.Pending(context.Background())
@@ -292,12 +294,12 @@ func TestExecutor(t *testing.T) {
 	require.Equal(t, "3_partly.sql", p[0].Name())
 
 	// Suppose first revision is already executed, only execute second migration file.
-	*rrw = mockRevisionReadWriter(migrate.Revisions{rev1})
+	*rrw = []*migrate.Revision{rev1}
 	*drv = mockDriver{}
 
 	require.NoError(t, ex.ExecuteN(context.Background(), 1))
 	require.Equal(t, []string{"ALTER TABLE t_sub ADD c2 int;"}, drv.executed)
-	requireEqualRevisions(t, migrate.Revisions{rev1, rev2}, migrate.Revisions(*rrw))
+	requireEqualRevisions(t, []*migrate.Revision{rev1, rev2}, *rrw)
 
 	// Partly is pending.
 	p, err = ex.Pending(context.Background())
@@ -306,19 +308,20 @@ func TestExecutor(t *testing.T) {
 	require.Equal(t, "3_partly.sql", p[0].Name())
 
 	// Failing, counter will be correct.
-	*rrw = mockRevisionReadWriter(migrate.Revisions{rev1, rev2})
+	*rrw = []*migrate.Revision{rev1, rev2}
 	*drv = mockDriver{}
 	drv.failOn(2, errors.New("this is an error"))
 	require.ErrorContains(t, ex.ExecuteN(context.Background(), 1), "this is an error")
 	revs, err := rrw.ReadRevisions(context.Background())
 	require.NoError(t, err)
 	requireEqualRevision(t, &migrate.Revision{
-		Version:     "3",
-		Description: "partly",
-		Type:        migrate.RevisionTypeExecute,
-		Applied:     1,
-		Total:       2,
-		Error:       "Statement:\nALTER TABLE t_sub ADD c4 int;\n\nError:\nthis is an error",
+		Version:         "3",
+		Description:     "partly",
+		Type:            migrate.RevisionTypeExecute,
+		Applied:         1,
+		Total:           2,
+		Error:           "Statement:\nALTER TABLE t_sub ADD c4 int;\n\nError:\nthis is an error",
+		OperatorVersion: "op",
 	}, revs[len(revs)-1])
 
 	// Will fail if applied contents hash has changed (like when editing a partially applied file to fix an error).
@@ -414,7 +417,7 @@ func TestExecutor_FromVersion(t *testing.T) {
 	ex, err = migrate.NewExecutor(drv, dir, rrw, migrate.WithLogger(log), migrate.WithFromVersion("4"))
 	require.NoError(t, err)
 	files, err = ex.Pending(context.Background())
-	require.EqualError(t, err, `starting point version "4" was not found in the migration directory`)
+	require.EqualError(t, err, `starting point version "4" not found in the migration directory`)
 	require.Nil(t, files)
 }
 
@@ -495,17 +498,17 @@ func (m *mockDriver) CheckClean(context.Context, *migrate.TableIdent) error {
 	return nil
 }
 
-type mockRevisionReadWriter migrate.Revisions
+type mockRevisionReadWriter []*migrate.Revision
 
-func (mockRevisionReadWriter) Ident() *migrate.TableIdent {
+func (*mockRevisionReadWriter) Ident() *migrate.TableIdent {
 	return nil
 }
 
-func (mockRevisionReadWriter) Exists(_ context.Context) (bool, error) {
+func (*mockRevisionReadWriter) Exists(_ context.Context) (bool, error) {
 	return true, nil
 }
 
-func (mockRevisionReadWriter) Init(_ context.Context) error {
+func (*mockRevisionReadWriter) Init(_ context.Context) error {
 	return nil
 }
 
@@ -521,7 +524,7 @@ func (rrw *mockRevisionReadWriter) WriteRevision(_ context.Context, r *migrate.R
 }
 
 func (rrw *mockRevisionReadWriter) ReadRevision(_ context.Context, v string) (*migrate.Revision, error) {
-	for _, r := range migrate.Revisions(*rrw) {
+	for _, r := range []*migrate.Revision(*rrw) {
 		if r.Version == v {
 			return r, nil
 		}
@@ -529,19 +532,19 @@ func (rrw *mockRevisionReadWriter) ReadRevision(_ context.Context, v string) (*m
 	return nil, migrate.ErrRevisionNotExist
 }
 
-func (rrw *mockRevisionReadWriter) ReadRevisions(context.Context) (migrate.Revisions, error) {
-	return migrate.Revisions(*rrw), nil
+func (rrw *mockRevisionReadWriter) ReadRevisions(context.Context) ([]*migrate.Revision, error) {
+	return *rrw, nil
 }
 
 func (rrw *mockRevisionReadWriter) clean() {
-	*rrw = mockRevisionReadWriter(migrate.Revisions{})
+	*rrw = []*migrate.Revision{}
 }
 
 type mockLogger []migrate.LogEntry
 
 func (m *mockLogger) Log(e migrate.LogEntry) { *m = append(*m, e) }
 
-func requireEqualRevisions(t *testing.T, expected, actual migrate.Revisions) {
+func requireEqualRevisions(t *testing.T, expected, actual []*migrate.Revision) {
 	require.Equal(t, len(expected), len(actual))
 	for i := range expected {
 		requireEqualRevision(t, expected[i], actual[i])
