@@ -17,12 +17,8 @@ import (
 	"ariga.io/atlas/sql/sqlcheck/destructive"
 )
 
-// NewDataDepend creates new data-depend analyzer.
-func NewDataDepend(*schemahcl.Resource) *datadepend.Analyzer {
-	var opts datadepend.Options
-	opts.Handler.AddNotNull = addNotNull
-	return datadepend.New(opts)
-}
+// codeImplicitUpdate is a MySQL specific code for reporting implicit update.
+var codeImplicitUpdate = sqlcheck.Code("MY101")
 
 func addNotNull(p *datadepend.ColumnPass) (diags []sqlcheck.Diagnostic, err error) {
 	// Two types of reporting, implicit rows update and
@@ -38,7 +34,8 @@ func addNotNull(p *datadepend.ColumnPass) (diags []sqlcheck.Diagnostic, err erro
 	}
 	implicitUpdate := func(tt, v string) {
 		diags = append(diags, sqlcheck.Diagnostic{
-			Pos: p.Change.Pos,
+			Code: codeImplicitUpdate,
+			Pos:  p.Change.Pos,
 			Text: fmt.Sprintf(
 				"Adding a non-nullable %q column %q on table %q without a default value implicitly sets existing rows with %s",
 				tt, p.Column.Name, p.Table.Name, v,
@@ -133,10 +130,16 @@ func addNotNull(p *datadepend.ColumnPass) (diags []sqlcheck.Diagnostic, err erro
 
 func init() {
 	sqlcheck.Register(mysql.DriverName, func(r *schemahcl.Resource) (sqlcheck.Analyzer, error) {
-		d, err := destructive.New(r)
+		ds, err := destructive.New(r)
 		if err != nil {
 			return nil, err
 		}
-		return sqlcheck.Analyzers{d, NewDataDepend(nil)}, nil
+		dd, err := datadepend.New(r, datadepend.Handler{
+			AddNotNull: addNotNull,
+		})
+		if err != nil {
+			return nil, err
+		}
+		return sqlcheck.Analyzers{ds, dd}, nil
 	})
 }
