@@ -38,7 +38,7 @@ func init() {
 }
 
 // evalSpec evaluates an Atlas DDL document into v using the input.
-func evalSpec(p *hclparse.Parser, v interface{}, input map[string]string) error {
+func evalSpec(p *hclparse.Parser, v any, input map[string]string) error {
 	var d doc
 	if err := hclState.Eval(p, &d, input); err != nil {
 		return err
@@ -72,7 +72,7 @@ func evalSpec(p *hclparse.Parser, v interface{}, input map[string]string) error
 }
 
 // MarshalSpec marshals v into an Atlas DDL document using a schemahcl.Marshaler.
-func MarshalSpec(v interface{}, marshaler schemahcl.Marshaler) ([]byte, error) {
+func MarshalSpec(v any, marshaler schemahcl.Marshaler) ([]byte, error) {
 	var d doc
 	switch s := v.(type) {
 	case *schema.Schema:
@@ -94,15 +94,15 @@ func MarshalSpec(v interface{}, marshaler schemahcl.Marshaler) ([]byte, error) {
 			d.Schemas = append(d.Schemas, doc.Schemas...)
 			d.Enums = append(d.Enums, doc.Enums...)
 		}
-		if err := specutil.QualifyReferencedTables(d.Tables, s); err != nil {
+		if err := specutil.QualifyDuplicates(d.Tables); err != nil {
+			return nil, err
+		}
+		if err := specutil.QualifyReferences(d.Tables, s); err != nil {
 			return nil, err
 		}
 	default:
 		return nil, fmt.Errorf("specutil: failed marshaling spec. %T is not supported", v)
 	}
-	if err := specutil.QualifyDuplicates(d.Tables); err != nil {
-		return nil, err
-	}
 	return marshaler.MarshalSpec(&d)
 }
 
@@ -117,7 +117,7 @@ var (
 		schemahcl.WithScopedEnums("table.foreign_key.on_delete", specutil.ReferenceVars...),
 	)
 	// MarshalHCL marshals v into an Atlas HCL DDL document.
-	MarshalHCL = schemahcl.MarshalerFunc(func(v interface{}) ([]byte, error) {
+	MarshalHCL = schemahcl.MarshalerFunc(func(v any) ([]byte, error) {
 		return MarshalSpec(v, hclState)
 	})
 	// EvalHCL implements the schemahcl.Evaluator interface.
@@ -351,19 +351,27 @@ func convertEnums(tables []*sqlspec.Table, enums []*Enum, r *schema.Realm) error
 	}
 	for _, t := range tables {
 		for _, c := range t.Columns {
-			if !c.Type.IsRef {
-				continue
+			var enum *Enum
+			switch {
+			case c.Type.IsRef:
+				n, err := enumName(c.Type)
+				if err != nil {
+					return err
+				}
+				e, ok := byName[n]
+				if !ok {
+					return fmt.Errorf("enum %q was not found", n)
+				}
+				enum = e
+			default:
+				n, ok := arrayType(c.Type.T)
+				if !ok || byName[n] == nil {
+					continue
+				}
+				enum = byName[n]
 			}
-			name, err := enumName(c.Type)
-			if err != nil {
-				return err
-			}
-			e, ok := byName[name]
-			if !ok {
-				return fmt.Errorf("enum %q was not found", name)
-			}
-			used[e] = struct{}{}
-			schemaE, err := specutil.SchemaName(e.Schema)
+			used[enum] = struct{}{}
+			schemaE, err := specutil.SchemaName(enum.Schema)
 			if err != nil {
 				return fmt.Errorf("extract schema name from enum refrence: %w", err)
 			}
@@ -387,7 +395,13 @@ func convertEnums(tables []*sqlspec.Table, enums []*Enum, r *schema.Realm) error
 			if !ok {
 				return fmt.Errorf("column %q not found in table %q", c.Name, t.Name)
 			}
-			cc.Type.Type = &schema.EnumType{T: e.Name, Schema: es, Values: e.Values}
+			e := &schema.EnumType{T: enum.Name, Schema: es, Values: enum.Values}
+			switch t := cc.Type.Type.(type) {
+			case *ArrayType:
+				t.Type = e
+			default:
+				cc.Type.Type = e
+			}
 		}
 	}
 	for _, e := range enums {
@@ -416,30 +430,28 @@ func enumRef(n string) *schemahcl.Ref {
 
 // schemaSpec converts from a concrete Postgres schema to Atlas specification.
 func schemaSpec(schem *schema.Schema) (*doc, error) {
-	var d doc
 	s, tbls, err := specutil.FromSchema(schem, tableSpec)
 	if err != nil {
 		return nil, err
 	}
-	d.Schemas = []*sqlspec.Schema{s}
-	d.Tables = tbls
-
-	enums := make(map[string]struct{})
+	d := &doc{
+		Tables:  tbls,
+		Schemas: []*sqlspec.Schema{s},
+	}
+	enums := make(map[string]bool)
 	for _, t := range schem.Tables {
 		for _, c := range t.Columns {
-			if t, ok := c.Type.Type.(*schema.EnumType); ok {
-				if _, ok := enums[t.T]; !ok {
-					d.Enums = append(d.Enums, &Enum{
-						Name:   t.T,
-						Schema: specutil.SchemaRef(s.Name),
-						Values: t.Values,
-					})
-					enums[t.T] = struct{}{}
-				}
+			if e, ok := hasEnumType(c); ok && !enums[e.T] {
+				d.Enums = append(d.Enums, &Enum{
+					Name:   e.T,
+					Schema: specutil.SchemaRef(s.Name),
+					Values: e.Values,
+				})
+				enums[e.T] = true
 			}
 		}
 	}
-	return &d, nil
+	return d, nil
 }
 
 // tableSpec converts from a concrete Postgres sqlspec.Table to a schema.Table.
